![alt pyCGNS](doc/images/intro-logo-small.png)

pyCGNS is a set of Python modules implementing the
[CFD General Notation System standard](https://cgns.github.io),
the standard of the CFD data representation.
The [user documentation](http://pycgns.github.io) is available online, it
contains the releases, the installation requirements and process, the usage docs
and the reference docs.

For more information concerning the CGNS standard please refer to cgns.github.io

For MS-Windows users, an unofficial version can be found on https://anaconda.org/conda-forge/pycgns

## CGNS Modules

- `CGNS.MAP` implements CGNS/Python physical representation of CGNS/SIDS
- `CGNS.PAT` has a large set of fonctions for CGNS/Python tree handling
- `CGNS.NAV` is a CGNS/Python tree browser
- `CGNS.VAL` checks CGNS/SIDS compliance of CGNS/Python trees
- `CGNS.APP` is a set of all-purpose utilities
- `CGNS.DAT` is not maintained today


## Bugs/Feature and issue tracking

Please use the [issue-tracker](https://github.com/pycgns/pycgns/issues) at github
to report bugs, evolution proposals and submit patches.

## License

The distribution and use of the pyCGNS software is covered by the LGPL v2.1 license.
